@@ -159,7 +159,7 @@ class BaseRecord(_BaseAndTableSettableMixin, _BaseRecordProtocol):
         return instance
 
     def __init__(self, _base_id: Optional[str] = None, _table_id: Optional[str] = None, **kwargs):
-        super().__init__(base_id=_base_id, table_id=_table_id)
+        super().__init__(base_id=_base_id, table_id=_table_id, record_cls=type(self))
         self._fields_values = {}
         self._orig_fields_values = {}
 
